( cd usr/lib ; rm -rf libAiksaurus-1.2.so.0 )
( cd usr/lib ; ln -sf libAiksaurus-1.2.so.0.0.1 libAiksaurus-1.2.so.0 )
( cd usr/lib ; rm -rf libAiksaurus.so )
( cd usr/lib ; ln -sf libAiksaurus-1.2.so.0.0.1 libAiksaurus.so )
( cd usr/lib ; rm -rf libAiksaurusGTK-1.2.so.0 )
( cd usr/lib ; ln -sf libAiksaurusGTK-1.2.so.0.0.1 libAiksaurusGTK-1.2.so.0 )
( cd usr/lib ; rm -rf libAiksaurusGTK.so )
( cd usr/lib ; ln -sf libAiksaurusGTK-1.2.so.0.0.1 libAiksaurusGTK.so )
